######################
imagedata-format-pdf
######################

# |Docs Badge| |buildstatus|  |coverage| |pypi|
|buildstatus|  |pypi|


Imagedata plugin for reading PDF files as encapsulated PDF.


.. |Docs Badge| image:: https://readthedocs.org/projects/imagedata/badge/
    :alt: Documentation Status
    :target: https://imagedata.readthedocs.io


.. |buildstatus| image:: https://github.com/erling6232/imagedata_format_pdf/actions/workflows/build_wheels.yml/badge.svg
    :target: https://github.com/erling6232/imagedata_format_pdf/actions?query=branch%3Amain
    :alt: Build Status

.. _buildstatus: https://github.com/erling6232/imagedata_format_pdf/actions

.. |coverage| image:: https://codecov.io/gh/erling6232/imagedata_format_pdf/branch/main/graph/badge.svg?token=5D3JDRKXZV
    :alt: Coverage
    :target: https://codecov.io/gh/erling6232/imagedata_format_pdf

.. |pypi| image:: https://img.shields.io/pypi/v/imagedata-format-pdf.svg
    :target: https://pypi.python.org/pypi/imagedata-format-pdf
    :alt: PyPI Version

